@@ -3,8 +3,8 @@ time manipulation utilities for python
 """
 
 from . import _version
-from .core import Timeline, run_async, run_sync
+from .core import Timeline, run_async, run_sync, run_threaded
 
-__all__ = ["run_async", "run_sync", "Timeline"]
+__all__ = ["run_threaded", "run_async", "run_sync", "Timeline"]
 
 __version__ = _version.get_versions()["version"]
