@@ -2,10 +2,9 @@
 patched builtin time classes for use by :class:`hiro.Timeline`
 """
 import abc
+import time
 from datetime import date as realdate
 from datetime import datetime as realdatetime
-import time
-import six
 
 
 class DatetimeMeta(abc.ABCMeta):
@@ -14,20 +13,23 @@ class DatetimeMeta(abc.ABCMeta):
     objects create inside the :class:`hiro.Timeline` with those created
     outside it.
     """
+
     def __instancecheck__(cls, instance):
         return isinstance(instance, realdatetime)
 
+
 class DateMeta(type):
     """
     meta class to allow interaction between :class:`datetime.date`
     objects create inside the :class:`hiro.Timeline` with those created
     outside it.
     """
+
     def __instancecheck__(cls, instance):
         return isinstance(instance, realdate)
 
-@six.add_metaclass(DatetimeMeta)
-class Datetime(realdatetime):
+
+class Datetime(realdatetime, metaclass=DatetimeMeta):
     """
     used to patch :class:`datetime.datetime` to follow the rules of the
     parent :class:`hiro.Timeline`
@@ -41,12 +43,13 @@ class Datetime(realdatetime):
     def utcnow(cls):
         return cls.utcfromtimestamp(time.time())
 
-@six.add_metaclass(DateMeta)
-class Date(realdate):
+
+class Date(realdate, metaclass=DateMeta):
     """
     used to patch :class:`datetime.date` to follow the rules of the
     parent :class:`hiro.Timeline`
     """
+
     __metaclass__ = DateMeta
 
     @classmethod
