@@ -1,21 +1,25 @@
 """
 
 """
-from datetime import datetime, date
-from time import time, sleep, gmtime
+from datetime import date, datetime
+from time import gmtime, sleep, time
 
 
 def sub_sample_3_1_now():
     return datetime.now()
 
+
 def sub_sample_3_1_today():
     return date.today()
 
+
 def sub_sample_3_1_sleep(seconds):
     sleep(seconds)
 
+
 def sub_sample_3_1_time():
     return time()
 
+
 def sub_sample_3_1_gmtime():
     return gmtime()
